@@ -4,6 +4,7 @@
 import collections
 import logging
 import subprocess
+
 if not hasattr(subprocess, "TimeoutExpired"):
     import subprocess32 as subprocess  # pylint: disable=import-error
 
@@ -22,17 +23,14 @@ def run_command(command, timeout=60, shell=True):
     :rtype: subprocess compatible ProcessResult
     :raises RuntimeError: If timeout expires.
     """
-    process = subprocess.Popen(command,
-                               shell=shell,
-                               stdin=subprocess.PIPE,
-                               stdout=subprocess.PIPE,
-                               stderr=subprocess.PIPE)
+    process = subprocess.Popen(
+        command, shell=shell, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+    )
     try:
         stdout, stderr = process.communicate(timeout=timeout)
     except subprocess.TimeoutExpired:
         process.terminate()
-        raise RuntimeError("Timeout %d seconds reached for command '%s'"
-                           % (timeout, command))
+        raise RuntimeError("Timeout %d seconds reached for command '%s'" % (timeout, command))
     if isinstance(stdout, bytes):
         stdout = stdout.decode("utf-8")
     if isinstance(stderr, bytes):
