@@ -15,6 +15,8 @@ from threading import Thread, Event
 from dlt.dlt import (
     DLTClient,
     DLT_DAEMON_TCP_PORT,
+    DLT_UDP_MULTICAST_BUFFER_SIZE,
+    DLT_UDP_MULTICAST_FD_BUFFER_SIZE,
     cDLT_FILE_NOT_OPEN_ERROR,
     load,
     py_dlt_client_main_loop,
@@ -400,6 +402,10 @@ class DLTMessageHandler(DLTMessageDispatcherBase):
         self.timeout = client_cfg.get("timeout", DLT_CLIENT_TIMEOUT)
         self._client = None
         self.tracefile = None
+        self.last_connected = time.time()
+        self.last_message = time.time() - 120.0
+        self._udp_fd_buffer_size_bytes = client_cfg.get("udp_fd_buffer_size_bytes", DLT_UDP_MULTICAST_FD_BUFFER_SIZE)
+        self._udp_buffer_size_bytes = client_cfg.get("udp_buffer_size_bytes", DLT_UDP_MULTICAST_BUFFER_SIZE)
 
     def is_valid_message(self, message):
         return message and (message.apid != "" or message.ctid != "")
@@ -411,13 +417,20 @@ class DLTMessageHandler(DLTMessageDispatcherBase):
         :returns: True if connected, False otherwise
         :rtype: bool
         """
-        logger.debug(
-            "Creating DLTClient (ip_address='%s', Port='%s', logfile='%s')",
-            self._ip_address,
-            self._port,
-            self._filename,
+        if self.verbose:
+            logger.debug(
+                "Creating DLTClient (ip_address='%s', Port='%s', logfile='%s')",
+                self._ip_address,
+                self._port,
+                self._filename,
+            )
+        self._client = DLTClient(
+            servIP=self._ip_address,
+            port=self._port,
+            verbose=self.verbose,
+            udp_fd_buffer_size_bytes=self._udp_fd_buffer_size_bytes,
+            udp_buffer_size_bytes=self._udp_buffer_size_bytes,
         )
-        self._client = DLTClient(servIP=self._ip_address, port=self._port, verbose=self.verbose)
         connected = self._client.connect(self.timeout)
         if connected:
             logger.info("DLTClient connected to %s", self._client.servIP)
@@ -434,11 +447,28 @@ class DLTMessageHandler(DLTMessageDispatcherBase):
             if not self._client_connect():
                 # keep trying to reconnect, until we either successfully
                 # connect or the stop_flag is set
+                if time.time() - self.last_message > 60:
+                    # Once per minute log that we still have no DLT Connection
+                    logger.info(
+                        "DLT connection to %s missing since %s seconds",
+                        self._ip_address,
+                        time.time() - self.last_connected,
+                    )
+                    self.last_message = time.time()
                 continue
             try:
+                if self.last_connected:
+                    logger.info(
+                        "DLT connection to %s re-established after %s seconds",
+                        self._ip_address,
+                        time.time() - self.last_connected,
+                    )
+                self.last_connected = time.time()
                 res = py_dlt_client_main_loop(self._client, verbose=0, callback=self.handle, dumpfile=self.tracefile)
                 if res is False and not self.mp_stop_flag.is_set():  # main loop returned False
-                    logger.error("DLT connection lost. Restarting DLT client")
+                    logger.warning("DLT connection to %s lost. Restarting DLT client", self._ip_address)
+                    self.last_connected = time.time()
+                    self.last_message = time.time()
                     exception_occured = True
             except KeyboardInterrupt:
                 exception_occured = True
